@@ -16,16 +16,22 @@ use App::Git::Workflow;
 use App::Git::Workflow::Command qw/get_options/;
 use DateTime::Format::HTTP;
 
-our $VERSION  = version->new(1.1.4);
+our $VERSION  = version->new(1.1.6);
 our $workflow = App::Git::Workflow->new;
 our ($name)   = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
-our %option;
+our %option = (
+    master => 'origin/master',
+);
 
 sub run {
     get_options(
         \%option,
+        'all|a',
         'remote|r',
-        'insensitive|i',
+        'reverse|R',
+        'unmerged|u!',
+        'master|m=s',
+        'limit|n=i',
     );
     my $fmt = join "-%09-%09-", qw/
         %(authordate)
@@ -72,10 +78,14 @@ sub run {
         if (@cols < @headings) {
             next;
         }
+
         $last = '';
         $branch = { zip @headings, @cols };
         warn 'bad head' if !$branch->{HEAD};
         next if !$branch->{HEAD};
+        if ( defined $option{unmerged} ) {
+            next if unmerged($branch->{short}, $option{master});
+        }
 
         my ($date, $tz) = $branch->{authordate} =~ /^(.*)\s+([+-]\d{4})$/;
         if ($date && $tz) {
@@ -93,11 +103,29 @@ sub run {
     if ($option{reverse}) {
         @data = reverse @data;
     }
+
+    my $count = 1;
     for my $branch (@data) {
+        last if $option{limit} && $count++ > $option{limit};
         printf "%s\t%s\n", $branch->{age}, $branch->{short};
     }
 }
 
+my @master;
+sub unmerged {
+    my ($branch, $master) = @_;
+
+    if ( ! @master ) {
+        @master = map {/^(.*)\n/; $1} `git log --format=format:%H $master`;
+        die "No master" if !@master;
+    }
+
+    my $source_sha = `git log --format=format:%H -n 1 $branch`;
+    chomp $source_sha;
+
+    return scalar grep {$_ && $_ eq $source_sha} @master;
+}
+
 1;
 
 __DATA__
@@ -108,7 +136,7 @@ git-branch-age - grep tags
 
 =head1 VERSION
 
-This documentation refers to git-branch-age version 1.1.4
+This documentation refers to git-branch-age version 1.1.6
 
 =head1 SYNOPSIS
 
@@ -116,6 +144,18 @@ This documentation refers to git-branch-age version 1.1.4
 
  OPTIONS:
   regex         grep's perl (-P) regular expression
+  -a --all      All branches (remote and local
+  -r --remote   Remote branches only
+  -R --reverse  Reverse the branch sort order
+  -u --unmerged
+                Only show branches not merged to --master
+     --no-unmerged
+                Only show branches merged to master
+  -m --master[=]str
+                Branch to check against for --unmerged and --no-unmerged
+                (Default origin/master)
+  -n --limit[=]int
+                Limit the out put to this number
 
   -v --verbose  Show more detailed option
      --version  Prints the version information
